function [indexCA] = findMyCAlpha (indexAtom, pdb)
% This function takes the index of an atom (indexAtom) and a pdb struct.
% It returns the CA atom index of the residue of atomIndex 
%
% E.g. if we parse (parsePdb.m) this file:
%
% ATOM   6364  N   THR E 109      73.680 103.410  26.880  1.00  0.00            
% ATOM   6365  H   THR E 109      74.580 103.070  27.170  1.00  0.00            
% ATOM   6366  CA  THR E 109      73.710 104.180  25.620  1.00  0.00            
% ATOM   6367  CB  THR E 109      74.900 105.120  25.420  1.00  0.00            
% ATOM   6368  OG1 THR E 109      75.170 105.660  26.720  1.00  0.00            
% ATOM   6369  HG1 THR E 109      75.160 106.650  26.660  1.00  0.00            
% ATOM   6370  CG2 THR E 109      74.530 106.210  24.420  1.00  0.00            
% ATOM   6371  C   THR E 109      73.890 103.160  24.500  1.00  0.00            
% ATOM   6372  O   THR E 109      74.890 102.450  24.440  1.00  0.00           
%
% [indexCA] = findMyCAlpha (6370, pdb) wil return 6366
%
% B. Knapp 2015-12-14

indexSearchStart = indexAtom - 25; % should be a maximum of 18 atoms before (in TRP) but to make sure we use 25
if indexSearchStart < 1 % avoid a negative index
    indexSearchStart = 1;
end

wasFound = false;

for idx = indexSearchStart:indexAtom + 25
    if idx >= length(pdb.atomNumber) % avoid out of bounds
        wasFound = false;
        break;
    end
    if (strcmp(pdb.atomName{idx}, 'CA')) && pdb.residueNumber(indexAtom) == pdb.residueNumber(idx)
        wasFound = true;
        break;
    end
end

if wasFound
    indexCA = idx;
else
    error ('no CA found for atom %1.0f\n', indexAtom);
end


