function[pdbOut] = selectAtoms (pdbIn,filter)

% selectionAtoms
% --------------
% 
% By declaration of the filter (specification of the atoms), the
% coordinates are coarse grained.
%
% In-parameter:
% -------------
%
% pdb: structur of constructorPdb ()
% 
% filter: Contains the information of the selection of the atoms (e.g.
% filter{1}: 'CA' filters only the C-alpha atoms of the backbone)
%
%
% Out-parameter:
% --------------
%
% pdb_new: structur like pdb (in-parameter), but with less coordinates (only CA-coordinates of the backbone) in
% pdb_new.coords
%
% Example:
% --------
% % Load the struct with discrete curves:
% loadPath=sprintf('exampleSelection.mat');
% load(loadPath,'pdbInfo_1ao7');
% % Select the atoms:
% filter{1}='CA';
% % Call the function:
% pdb_new=selectionAtoms(pdbInfo_1ao7,filter);
%
% See also: selectAAs
%
% B. Knapp 2014-03-10 partly based on B. Hischenhuber


[nrOfAtoms,nrOfDimensions,nrOfTimeSteps]=size(pdbIn.coords);
sizeFilter=size(filter);

pdbOut=constructorPdb();
pdbOut.coords=zeros(1,nrOfDimensions,nrOfTimeSteps);
fillCtr=1;

for atomIter=1:nrOfAtoms
    for filterIter=1:sizeFilter(2)
        if(isequal(filter{1,filterIter},pdbIn.atomName{atomIter})==1)
            pdbOut.coords(fillCtr,:,:)=pdbIn.coords(atomIter,:,:);
            pdbOut.coordsUnit=pdbIn.coordsUnit;
            pdbOut.recordName{fillCtr}=pdbIn.recordName{atomIter};
            pdbOut.atomNumber(fillCtr)=pdbIn.atomNumber(atomIter);
            pdbOut.atomName{fillCtr}=pdbIn.atomName{atomIter};
            pdbOut.alternateLocationIndicator{fillCtr}=pdbIn.alternateLocationIndicator{atomIter};
            pdbOut.residueName{fillCtr}=pdbIn.residueName{atomIter};
            pdbOut.chainIdentifier{fillCtr}=pdbIn.chainIdentifier{atomIter};
            pdbOut.residueNumber(fillCtr)=pdbIn.residueNumber(atomIter);
            if isfield (pdbIn, 'insertionCode') % field might not exists if it is computationally created data e.g. with MOSAICS
                pdbOut.insertionCode{fillCtr}=pdbIn.insertionCode{atomIter};
            end
            if isfield (pdbIn, 'occupancy')
                pdbOut.occupancy(fillCtr)=pdbIn.occupancy(atomIter);
            end
            if isfield (pdbIn, 'temperatureFactor')
                pdbOut.temperatureFactor(fillCtr)=pdbIn.temperatureFactor(atomIter);
            end
            if isfield (pdbIn, 'element')
                pdbOut.element{fillCtr}=pdbIn.element{atomIter};
            end
            if isfield (pdbIn, 'atomCharge')
                pdbOut.atomCharge(fillCtr)=pdbIn.atomCharge(atomIter);
            end
            if isfield (pdbIn, 'information')
                pdbOut.information=pdbIn.information;
            end
            fillCtr=fillCtr+1;
        end
    end
end
end
