function [] = writeVmdFileForHBondPlots_basedOnMtx (mtx, pdb, fn, th, furtherVmdCmd)
% this function writes a human readable statement and a VMD visualisation
% command about the existing h-bonds based on an hbond existance matrix
% that was previously created by
%
% The input of the function comes from
%
% parseHBond_allOutput.m and then createFullHBondMatrix_from_parseHBond_allOutput.m
%
% e.g.
%
% baseFn = '/data/housemartin/knapp/matlabWorkspace/util/parsing/ascii/g5_h-bond/';
%
% [hBondMatrix, hBondNdxData, hBondNum, pdb, allAtomMtxGroup1, allAtomMtxGroup2, allResMtxGroup1, allResMtxGroup2] = parseHBond_allOutput ([baseFn, 'test.hbm.xpm'], [baseFn, 'test.hbn.ndx'], [baseFn, 'hBondNum.xvg'], [baseFn, 'JM22.firstFrame.pdb'],  false);
%
% writeVmdFileForHBondPlots (hBondNdxData, hBondMatrix, pdb, false, true);
%
% [fullMtx] = createFullHBondMatrix_from_parseHBond_allOutput (hBondNdxData, hBondMatrix, pdb);
% writeVmdFileForHBondPlots_basedOnMtx (fullMtx, pdb, [pdb.sourceFileName, '.hbond.fromMtx.CA.vmdCmds.txt'], 0.0001)
%
% B. Knapp 2015-12-14

% colorStr = sprintf('draw color %s\n', myColor);

% pdb.coords = nanometer2angstroem(pdb.coords);

pdbCA = selectAtoms(pdb, {'CA'});
pdbCA.coords = nanometer2angstroem(pdbCA.coords);

% fnVmdOut = [pdb.sourceFileName(1:end-4), '.hbond.vmdCmds.txt'];
fnVmdOut = fn;

fileID_VMD = fopen(fnVmdOut, 'w');
fprintf (fileID_VMD, '%s\n', 'mol addrep 0');
fprintf (fileID_VMD, '%s\n', 'display resetview');
fprintf (fileID_VMD, '%s\n', ['mol new {', pdb.sourceFileName, '} type {pdb} first 0 last -1 step 1 waitfor 1']);
fprintf (fileID_VMD, '%s\n', 'animate style Loop');
fprintf (fileID_VMD, '%s\n', 'menu graphics off');
fprintf (fileID_VMD, '%s\n', 'menu graphics on');
fprintf (fileID_VMD, '%s\n', 'mol modcolor 0 0 ColorID 0');
fprintf (fileID_VMD, '%s\n', 'mol modselect 0 0 chain A');
fprintf (fileID_VMD, '%s\n', 'mol modstyle 0 0 NewCartoon 0.300000 10.000000 4.100000 0');
fprintf (fileID_VMD, '%s\n', 'mol color ColorID 8');
fprintf (fileID_VMD, '%s\n', 'mol representation NewCartoon 0.300000 10.000000 4.100000 0');
fprintf (fileID_VMD, '%s\n', 'mol selection chain A and resid 1 to 180');
fprintf (fileID_VMD, '%s\n', 'mol material Opaque');
fprintf (fileID_VMD, '%s\n', 'mol addrep 0');
fprintf (fileID_VMD, '%s\n', 'mol modselect 1 0 chain C');
fprintf (fileID_VMD, '%s\n', 'mol modcolor 1 0 ColorID 11');
fprintf (fileID_VMD, '%s\n', 'mol modcolor 1 0 ColorID 7');
fprintf (fileID_VMD, '%s\n', 'mol modstyle 1 0 NewCartoon 0.350000 10.000000 4.100000 0');
fprintf (fileID_VMD, '%s\n', 'mol modstyle 1 0 NewCartoon 0.410000 10.000000 4.100000 0');
fprintf (fileID_VMD, '%s\n', 'mol color ColorID 11');
fprintf (fileID_VMD, '%s\n', 'mol representation NewCartoon 0.410000 10.000000 4.100000 0');
fprintf (fileID_VMD, '%s\n', 'mol selection chain C');
fprintf (fileID_VMD, '%s\n', 'mol material Opaque');
fprintf (fileID_VMD, '%s\n', 'mol addrep 0');
fprintf (fileID_VMD, '%s\n', 'mol modselect 2 0 chain D');
fprintf (fileID_VMD, '%s\n', 'mol modcolor 2 0 ColorID 3');
fprintf (fileID_VMD, '%s\n', 'mol color ColorID 3');
fprintf (fileID_VMD, '%s\n', 'mol representation NewCartoon 0.410000 10.000000 4.100000 0');
fprintf (fileID_VMD, '%s\n', 'mol selection chain D');
fprintf (fileID_VMD, '%s\n', 'mol material Opaque');
fprintf (fileID_VMD, '%s\n', 'mol addrep 0');
fprintf (fileID_VMD, '%s\n', 'mol modselect 3 0 chain E');
fprintf (fileID_VMD, '%s\n', 'mol modcolor 3 0 ColorID 16');
fprintf (fileID_VMD, '%s\n', 'mol modcolor 0 0 ColorID 8');

fprintf (fileID_VMD, '%s\n', 'mol addrep 0');
fprintf (fileID_VMD, '%s\n', 'mol modselect 4 0 chain B');
fprintf (fileID_VMD, '%s\n', 'mol modcolor 4 0 ColorID 8');

if nargin > 4
    
    fprintf (fileID_VMD, furtherVmdCmd);
    
end

fprintf (fileID_VMD, '%s\n', 'display depthcue off');
fprintf (fileID_VMD, '%s\n', 'display projection Orthographic');
fprintf (fileID_VMD, '\n\n\n');



% fprintf (fileID_VMD, '%s', colorStr); % write to file


for hBondIter1 = 1:size(mtx, 1)
    for hBondIter2 = 1:hBondIter1 % only half of the matrix needed
        
        myRadius = mtx (hBondIter1, hBondIter2);
        
        %%%% use this for interaction specific coloring
        %%%% color by interaction type (TCR, peptide, MHC):
        %         ch1 = pdbCA.chainIdentifier{hBondIter1};
        %         ch2 = pdbCA.chainIdentifier{hBondIter2};
        %         if  (strcmp ('A', ch1) && strcmp ('D', ch2)) || (strcmp ('A', ch1) && strcmp ('E', ch2)) || ... % take only if between MHC and TCR
        %                 (strcmp ('D', ch1) && strcmp ('A', ch2)) || (strcmp ('E', ch1) && strcmp ('A', ch2))
        %             fprintf (fileID_VMD, 'draw color blue\n');
        %         elseif  (strcmp ('C', ch1) && strcmp ('D', ch2)) || (strcmp ('C', ch1) && strcmp ('E', ch2)) || ... % take only if between peptide and TCR
        %                 (strcmp ('D', ch1) && strcmp ('C', ch2)) || (strcmp ('E', ch1) && strcmp ('C', ch2))
        %             fprintf (fileID_VMD, 'draw color red\n');
        %         else % all other H-bonds are white
        %             fprintf (fileID_VMD, 'draw color white\n');
        %         end
        
        %%%% color by difference (only useful if 2 matrices where substracted before
        if myRadius > th
            fprintf (fileID_VMD, 'draw color blue\n');
        elseif myRadius < -th
            fprintf (fileID_VMD, 'draw color red\n');
        end
        
        if abs(myRadius) > th % only draw big enough differences
            vmdStr = sprintf('draw cylinder {%1.3f %1.3f %1.3f} {%1.3f %1.3f %1.3f} radius %1.2f; # res %s%i(%s)-%s%i(%s) \n',  ...
                pdbCA.coords(hBondIter1, 1), pdbCA.coords(hBondIter1, 2), pdbCA.coords(hBondIter1, 3), ...
                pdbCA.coords(hBondIter2, 1), pdbCA.coords(hBondIter2, 2), pdbCA.coords(hBondIter2, 3), abs(myRadius), ...
                pdbCA.residueName{hBondIter1}, pdbCA.residueNumber(hBondIter1), pdbCA.chainIdentifier{hBondIter1}, ...
                pdbCA.residueName{hBondIter2}, pdbCA.residueNumber(hBondIter2), pdbCA.chainIdentifier{hBondIter2} ...
                );

            fprintf (fileID_VMD, vmdStr);
        end
        
    end
    
end

fclose(fileID_VMD);


fprintf ('Visualisation written to "%s". The content of this file can be copy&pasted into VMD => extensions => Tk Console. \n', fnVmdOut);


